@@ -26,11 +26,11 @@ Lavoco::Web::App - Experimental framework with two constraints: FastCGI and Temp
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 $VERSION = eval $VERSION;
 
@@ -251,7 +251,11 @@ sub _init
     my $config = undef;
 
     eval {
-        $config = decode_json $string;
+        my $json = JSON->new;
+
+        $json->relaxed( 1 );
+
+        $config = $json->decode( $string );
     };
 
     if ( $@ )
@@ -671,7 +675,11 @@ sub _reload_config
     my $config = undef;
 
     eval {
-        $self->config( decode_json $string );
+        my $json = JSON->new;
+
+        $json->relaxed( 1 );
+
+        $self->config( $json->decode( $string ) );
     };
 
     $log->debug( $@ ) if $@;
